@@ -18,7 +18,7 @@ use Exporter 'import';
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 1;
 
@@ -42,11 +42,31 @@ The module provides methods to query the blockchain of the crypto coin Tron.
 
 =head1 SEE ALSO
 
-Try::Catch
+CryptoTron modules:
 
-Inline::Python
+  CryptoTron::SignTx
 
-Bitcoin::Crypto::Base58
+  CryptoTron::AddrTools
+
+  CryptoTron::AddressConvert
+
+  CryptoTron::AddressCheck
+
+  CryptoTron::ClaimReward
+
+CPAN modules:
+
+  URI
+
+  LWP::UserAgent
+
+  JSON::PP
+
+  Try::Catch
+
+  Inline::Python
+
+  Bitcoin::Crypto::Base58
 
 =head1 AUTHOR
 
