@@ -10,7 +10,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK);
 use Exporter 'import';
 
 # Exporting the implemented subroutine.
-our @EXPORT = qw(WithdrawBalance
+our @EXPORT = qw(ClaimReward
                  TransactionBuilder
                  BroadcastTransaction
                  parse_txID
@@ -23,7 +23,7 @@ our @EXPORT = qw(WithdrawBalance
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 # Load the required Perl modules or packages.
 use URI;
@@ -47,26 +47,27 @@ def sign_txID(txID, privKey):
 
 END_OF_PYTHON_CODE
 
+# Create alias.
 *sign = \&sign_txID;
 
-# Set the variable $JSON.
+# Set up the options for the Perl module JSON::PP.
 our $JSON = 'JSON::PP'->new->pretty;
 
 # Define the global variables.
-our($HEADER, $SERVICE_URL_0, $SERVICE_URL_1);
+our($HEADER, $SERVICE_URL_PRE, $SERVICE_URL_POST);
 
 # Set api url and api path.
 our $API_URL = 'https://api.trongrid.io';
-our $API_PATH_0 = '/wallet/withdrawbalance';
-our $API_PATH_1 = '/wallet/broadcasttransaction';
+our $API_PATH_PRE = '/wallet/withdrawbalance';
+our $API_PATH_POST = '/wallet/broadcasttransaction';
 
 # Set the request header.
 $HEADER = [Accept => 'application/json',
            Content_Type => 'application/json'];
 
 # Assemble the service url.
-$SERVICE_URL_0 = $API_URL.$API_PATH_0;
-$SERVICE_URL_1 = $API_URL.$API_PATH_1;
+$SERVICE_URL_PRE = $API_URL.$API_PATH_PRE;
+$SERVICE_URL_POST = $API_URL.$API_PATH_POST;
 
 # ---------------------------------------------------------------------------- #
 # Subroutine encode()                                                          #
@@ -76,17 +77,15 @@ $SERVICE_URL_1 = $API_URL.$API_PATH_1;
 # from the HTTP response using the method POST.                                #
 #                                                                              #
 # @argument $content      Response content  (scalar)                           #
-# @returns  $json_encode  Encoded content   (scalar)                           #
+# @return   $json_encode  Encoded content   (scalar)                           #
 # ---------------------------------------------------------------------------- #
 sub encode {
     # Assign the argument to the local variable.
     my $content = $_[0];
-    # Set up the options for the Perl module JSON::PP.
-    my $json = 'JSON::PP'->new->pretty;
     # Decode the content from the response.
-    my $json_decode = $json->decode($content);
+    my $json_decode = $JSON->decode($content);
     # Encode the decoded content from the response.
-    my $json_encode = $json->encode($json_decode);
+    my $json_encode = $JSON->encode($json_decode);
     # Return the encoded content.
     return $json_encode;
 };
@@ -102,19 +101,18 @@ sub encode {
 # @return   $content      Response content  (scalar)                           #
 # ---------------------------------------------------------------------------- #
 sub get_response {
-    # Assign the argument to the local variable.
+    # Assign the subroutine arguments to the local variables.
     my $payload = $_[0];
     my $service_url = $_[1];
     # Declare the variable $content.
     my $content = "";
     # Create a new uri object.
-    #my $uri = URI->new($SERVICE_URL_0);
     my $uri = URI->new($service_url);
     # Create a new user agent object.
     my $ua = LWP::UserAgent->new;
     # Get the response from the uri.
     my $response = $ua->post($uri, $HEADER, Content => $payload);
-    # Check success of operation.
+    # Check the success of the operation.
     if ($response->is_success) {
         # Get the content from the response.
         $content = $response->content;
@@ -123,20 +121,6 @@ sub get_response {
     return $content;
 };
 
-# ---------------------------------------------------------------------------- #
-# Subroutine create_payload()                                                  # 
-# ---------------------------------------------------------------------------- #
-sub create_payload {
-    # Assign the subroutine arguments to the local variables.
-    my ($address) = (defined $_[0] ? $_[0] : '');
-    # Create the payload string.
-    # This is not working! We need a HEX address!   
-    # my $payload = "\{\"owner_address\":\"$address\",\"visible\":\"True\"\}";
-    my $payload = "\{\"owner_address\":\"$address\"}";
-    # Return the payload string.
-    return $payload
-};
-
 # ---------------------------------------------------------------------------- #
 # Subroutine TransactionBuilder()                                              #
 #                                                                              #
@@ -145,8 +129,8 @@ sub create_payload {
 # the Tron blockchain. This balance is the reward which is available every 24  #  
 # hours.                                                                       #
 #                                                                              #
-# @argument $privKey    Private Key         (scalar)                           #
-#           $flag       Output format flag  (scalar)                           # 
+# @argument $address    Public key          (scalar)                           #
+#           $outflag    Output format flag  (scalar)                           # 
 # @return   $json_data  Response content    (scalar)                           #
 # ---------------------------------------------------------------------------- #
 sub TransactionBuilder {
@@ -166,12 +150,13 @@ sub TransactionBuilder {
     my $content = "";
     # Check address.
     if ($address ne "") {
-        # Assemble the payload from the address.
-        $payload = create_payload($address); 
+        # Create the payload string.
+        $payload = "\{\"owner_address\":\"$address\"}";
         # Get the content from the service url.
-        $content = get_response($payload, $SERVICE_URL_0);
+        $content = get_response($payload, $SERVICE_URL_PRE);
         # Format the content for the output.
         if ($outflag eq "RAW") {
+            # Set the json data.
             $json_data = $content;    
         } else {
             # Encode the content.
@@ -193,15 +178,15 @@ sub BroadcastTransaction {
     # Create the payload.
     my $payload = "\{\"raw_data\":$raw_data,\"raw_data_hex\": \"$raw_data_hex\",\"signature\":[\"$signature\"]\}";
     # Get the content from the response.
-    my $content = get_response($payload, $SERVICE_URL_1);
+    my $content = get_response($payload, $SERVICE_URL_POST);
     # Return the content.
     return $content;
 };
 
 # ---------------------------------------------------------------------------- #
-# Subroutine WithdrawBalance()                                                 #
+# Subroutine ClaimReward()                                                     #
 # ---------------------------------------------------------------------------- #
-sub WithdrawBalance {
+sub ClaimReward {
     # Assign the subroutine arguments to the local variables.
     my ($args) = @_;
     # Set the local variables.
@@ -219,12 +204,16 @@ sub WithdrawBalance {
     my $raw_data;
     my $raw_data_hex;
     my $signature;
+    # Try to get the transaction ID.
     my $txID = parse_txID($response);
     # Check if $txID is defined.
     if (defined $txID) {
+        # Get raw data and raw data hex.
         $raw_data_hex = parse_raw_data_hex($response);
         $raw_data = parse_raw_data($response);
+        # Sign transaction. 
         $signature = sign_txID($txID, $privAddr);
+        # Get the content from broadcast.
         $content = BroadcastTransaction($signature, $raw_data_hex, $raw_data);
     } else {
         $content = "{}";
@@ -283,30 +272,28 @@ __END__
 
 =head1 NAME
 
-CryptoTron::WithdrawBalance - Perl extension for use with the blockchain of the crypto coin Tron.
+CryptoTron::ClaimReward - Perl extension for use with the blockchain of the crypto coin Tron.
 
 =head1 SYNOPSIS
 
-  use CryptoTron::GetAccount;
+  use CryptoTron::ClaimReward;
 
-  # Declare the public keys.
-  my $PublicKeyBase58 = 'TQHgMpVzWkhSsRB4BzZgmV8uW4cFL8eaBr';
-
-  # Set the output format flag.
-  my $OutputFlag = ["RAW"|"STR"];
-
-  # Get the account info as JSON string.
-  my $account_info = GetAccount({
-      address => $PublicKeyBase58,
-      [flag    => $OutputFlag]
+  # Set the public and private key.
+  my $PublicKey = "4113661E105128E9918D50CC9F6ABD83DE10C302FC";
+  my $PrivateKey = "315763645E812CD269A326F6A59B971F31101BCB91190503B6C279B63D81A725";
+  
+  # Get the response from claiming rewards.
+  my $response = ClaimReward({
+      pubAddr => $PublicKey,
+      privAddr => $PrivateKey
   });
 
-  # Print the account info into the terminal window.
-  print $account_info;
+  # Print the response into the terminal window.
+  print $response;
 
 =head1 DESCRIPTION
 
-None
+Claim rewards from the Tron blockchain.
 
 =head1 SEE ALSO
 
